@@ -551,8 +551,8 @@
 /* #undef USE_SYMDIR */
 
 /* Character sets and collations */
-#define MYSQL_DEFAULT_CHARSET_NAME "utf8"
-#define MYSQL_DEFAULT_COLLATION_NAME "utf8_general_ci"
+#define MYSQL_DEFAULT_CHARSET_NAME "utf8mb4"
+#define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_unicode_ci"
 
 #define USE_MB 1
 #define USE_MB_IDENT 1
@@ -634,23 +634,23 @@
 #define MYSQL_DATADIR "/var/lib/mysql"
 #define DEFAULT_CHARSET_HOME "/usr"
 #define PLUGINDIR "/usr/lib/mysql/plugin"
-/* #undef DEFAULT_SYSCONFDIR */
+#define DEFAULT_SYSCONFDIR "/etc/mysql"
 #define DEFAULT_TMPDIR P_tmpdir
 
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 20
+#define MYSQL_VERSION_PATCH 21
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.20"
+#define PACKAGE_STRING "MySQL Server 10.1.21"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.20"
-#define VERSION "10.1.20"
+#define PACKAGE_VERSION "10.1.21"
+#define VERSION "10.1.21"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
